@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,27 +16,29 @@
  */
 package org.apache.qpid.jms.provider.failover;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-import static org.junit.Assume.assumeFalse;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.net.InetAddress;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.util.URISupport;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestInfo;
 
 /**
  * Test for the behavior of the FailoverUriPool
@@ -46,9 +48,9 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
     private List<URI> uris;
 
     @Override
-    @Before
-    public void setUp() throws Exception {
-        super.setUp();
+    @BeforeEach
+    public void setUp(TestInfo testInfo) throws Exception {
+        super.setUp(testInfo);
 
         uris = new ArrayList<URI>();
 
@@ -113,6 +115,17 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
         assertEquals(uris.get(0), pool.getNext());
     }
 
+    @Test
+    public void testGetSetRandomize() {
+        FailoverUriPool pool = new FailoverUriPool(uris, null);
+        assertFalse(pool.isEmpty());
+        assertFalse(pool.isRandomize());
+        pool.setRandomize(true);
+        assertTrue(pool.isRandomize());
+        pool.setRandomize(false);
+        assertFalse(pool.isRandomize());
+    }
+
     @Test
     public void testDuplicatesNotAdded() {
         FailoverUriPool pool = new FailoverUriPool(uris, null);
@@ -124,83 +137,97 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
         assertEquals(uris.size(), pool.size());
     }
 
+    @Test
+    public void testDuplicatesNotAddedByAddFirst() {
+        FailoverUriPool pool = new FailoverUriPool(uris, null);
+
+        assertEquals(uris.size(), pool.size());
+        pool.addFirst(uris.get(0));
+        assertEquals(uris.size(), pool.size());
+        pool.addFirst(uris.get(1));
+        assertEquals(uris.size(), pool.size());
+    }
+
     @Test
     public void testDuplicatesNotAddedWhenQueryPresent() throws URISyntaxException {
         FailoverUriPool pool = new FailoverUriPool();
 
         assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://127.0.0.1:5672?transport.tcpNoDelay=true"));
+        pool.add(new URI("tcp://localhost:5671?transport.tcpNoDelay=true"));
         assertFalse(pool.isEmpty());
 
         assertEquals(1, pool.size());
         pool.add(new URI("tcp://localhost:5672?transport.tcpNoDelay=true"));
-        assertEquals(1, pool.size());
+        assertEquals(2, pool.size());
 
-        assertEquals(1, pool.size());
+        assertEquals(2, pool.size());
         pool.add(new URI("tcp://localhost:5672?transport.tcpNoDelay=false"));
-        assertEquals(1, pool.size());
+        assertEquals(2, pool.size());
     }
 
     @Test
-    public void testDuplicatesNotAddedWithHostResolution() throws URISyntaxException {
+    public void testNoHostResolutionPerformedFilterDuplicatesOnly() throws URISyntaxException {
         FailoverUriPool pool = new FailoverUriPool();
 
         assertTrue(pool.isEmpty());
         pool.add(new URI("tcp://127.0.0.1:5672"));
         assertFalse(pool.isEmpty());
+        assertEquals(1, pool.size());
+
+        assertFalse(pool.isEmpty());
+        pool.add(new URI("tcp://127.0.0.1:5672"));  // Not added as it duplicates previous
+        assertFalse(pool.isEmpty());
+        assertEquals(1, pool.size());
+
+        pool.add(new URI("tcp://localhost:5672"));  // Added since there is no host resolution
+        assertEquals(2, pool.size());
+
+        pool.add(new URI("tcp://localhost:5673"));  // Added since the port is different
+        assertEquals(3, pool.size());
+
+        pool.add(new URI("tcp://localhost:5672"));  // Not added as it duplicates previous
+        assertEquals(3, pool.size());
+    }
+
+    @Test
+    public void testDuplicatesNotAddedWhenCaseIsDifferent() throws Exception {
+        FailoverUriPool pool = new FailoverUriPool();
+
+        assertTrue(pool.isEmpty());
+        pool.add(new URI("tcp://somerandomhostname:5672"));
+        assertFalse(pool.isEmpty());
 
         assertEquals(1, pool.size());
-        pool.add(new URI("tcp://localhost:5672"));
+        pool.add(new URI("tcp://SomerandomHostname:5672"));
         assertEquals(1, pool.size());
 
         assertEquals(1, pool.size());
-        pool.add(new URI("tcp://localhost:5673"));
+        pool.add(new URI("tcp://SOMERANDOMHOSTNAME:5672"));
+        assertEquals(1, pool.size());
+
+        assertEquals(1, pool.size());
+        pool.add(new URI("tcp://SOMERANDOMHOSTNAME2:5672"));
         assertEquals(2, pool.size());
     }
 
     @Test
-    public void testDuplicatesNotAddedUnresolvable() throws Exception {
-        assumeFalse("Host resolution works when not expected", checkIfResolutionWorks());
-
+    public void testDuplicatesNotAddedWhenCaseIsDifferentAndQueryStringPresent() throws URISyntaxException {
         FailoverUriPool pool = new FailoverUriPool();
 
         assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672"));
+        pool.add(new URI("tcp://somerandomhostname:5672?transport.tcpNoDelay=true"));
         assertFalse(pool.isEmpty());
 
         assertEquals(1, pool.size());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672"));
+        pool.add(new URI("tcp://SomerandomHostname:5672?transport.tcpNoDelay=false"));
         assertEquals(1, pool.size());
 
         assertEquals(1, pool.size());
-        pool.add(new URI("tcp://SHOULDBEUNRESOLVABLE:5672"));
+        pool.add(new URI("tcp://SOMERANDOMHOSTNAME:5672?transport.tcpNoDelay=true"));
         assertEquals(1, pool.size());
 
         assertEquals(1, pool.size());
-        pool.add(new URI("tcp://SHOULDBEUNRESOLVABLE2:5672"));
-        assertEquals(2, pool.size());
-    }
-
-    @Test
-    public void testDuplicatesNotAddedWhenQueryPresentAndUnresolveable() throws URISyntaxException {
-        assumeFalse("Host resolution works when not expected", checkIfResolutionWorks());
-
-        FailoverUriPool pool = new FailoverUriPool();
-
-        assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672?transport.tcpNoDelay=true"));
-        assertFalse(pool.isEmpty());
-
-        assertEquals(1, pool.size());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672?transport.tcpNoDelay=false"));
-        assertEquals(1, pool.size());
-
-        assertEquals(1, pool.size());
-        pool.add(new URI("tcp://SHOULDBEUNRESOLVABLE:5672?transport.tcpNoDelay=true"));
-        assertEquals(1, pool.size());
-
-        assertEquals(1, pool.size());
-        pool.add(new URI("tcp://SHOULDBEUNRESOLVABLE2:5672?transport.tcpNoDelay=true"));
+        pool.add(new URI("tcp://SOMERANDOMHOSTNAME2:5672?transport.tcpNoDelay=true"));
         assertEquals(2, pool.size());
     }
 
@@ -276,6 +303,37 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
         assertEquals(uris.get(0), pool.getNext());
     }
 
+    @Test
+    public void testAddAllHandlesNulls() throws URISyntaxException {
+        FailoverUriPool pool = new FailoverUriPool(uris, null);
+        pool.setRandomize(false);
+        pool.addAll(null);
+
+        assertEquals(uris.size(), pool.size());
+    }
+
+    @Test
+    public void testAddAllHandlesEmpty() throws URISyntaxException {
+        FailoverUriPool pool = new FailoverUriPool(uris, null);
+        pool.setRandomize(false);
+        pool.addAll(Collections.emptyList());
+
+        assertEquals(uris.size(), pool.size());
+    }
+
+    @Test
+    public void testAddAll() throws URISyntaxException {
+        FailoverUriPool pool = new FailoverUriPool(null, null);
+        pool.setRandomize(false);
+
+        assertEquals(0, pool.size());
+        assertFalse(uris.isEmpty());
+
+        pool.addAll(uris);
+
+        assertEquals(uris.size(), pool.size());
+    }
+
     @Test
     public void testRemoveURIFromPool() throws URISyntaxException {
         FailoverUriPool pool = new FailoverUriPool(uris, null);
@@ -299,60 +357,54 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
         assertTrue(pool.isEmpty());
         pool.add(new URI("tcp://127.0.0.1:5672?transport.tcpNoDelay=true"));
         assertFalse(pool.isEmpty());
-        pool.remove(new URI("tcp://localhost:5672?transport.tcpNoDelay=true"));
-        assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://127.0.0.1:5672?transport.tcpNoDelay=true"));
-        assertFalse(pool.isEmpty());
-        pool.remove(new URI("tcp://localhost:5672?transport.tcpNoDelay=false"));
+        pool.remove(new URI("tcp://127.0.0.1:5672?transport.tcpNoDelay=true"));
         assertTrue(pool.isEmpty());
     }
 
     @Test
-    public void testRemoveWithHostResolution() throws URISyntaxException {
+    public void testRemove() throws URISyntaxException {
         FailoverUriPool pool = new FailoverUriPool();
 
         assertTrue(pool.isEmpty());
         pool.add(new URI("tcp://127.0.0.1:5672"));
         assertFalse(pool.isEmpty());
-        pool.remove(new URI("tcp://localhost:5672"));
+        pool.remove(new URI("tcp://127.0.0.1:5672"));
         assertTrue(pool.isEmpty());
         pool.add(new URI("tcp://127.0.0.1:5672"));
         assertFalse(pool.isEmpty());
+        pool.add(new URI("tcp://127.0.0.1:5673"));
+        assertFalse(pool.isEmpty());
         pool.remove(new URI("tcp://localhost:5673"));
         assertFalse(pool.isEmpty());
     }
 
     @Test
-    public void testRemoveWhenUnresolvable() throws URISyntaxException {
-        assumeFalse("Host resolution works when not expected", checkIfResolutionWorks());
-
+    public void testRemoveHostIgnoresCaseInHostname() throws URISyntaxException {
         FailoverUriPool pool = new FailoverUriPool();
 
         assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672"));
+        pool.add(new URI("tcp://somerandomhostname:5672"));
         assertFalse(pool.isEmpty());
-        pool.remove(new URI("tcp://SHOULDBEUNRESOLVABLE:5672"));
+        pool.remove(new URI("tcp://SOMERANDOMHOSTNAME:5672"));
         assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672"));
+        pool.add(new URI("tcp://somerandomhostname:5672"));
         assertFalse(pool.isEmpty());
-        pool.remove(new URI("tcp://shouldbeunresolvable:5673"));
+        pool.remove(new URI("tcp://somerandomhostname:5673"));
         assertFalse(pool.isEmpty());
     }
 
     @Test
-    public void testRemoveWhenQueryPresentAndUnresolveable() throws URISyntaxException {
-        assumeFalse("Host resolution works when not expected", checkIfResolutionWorks());
-
+    public void testRemoveWhenQueryPresentIgnoresCaseInHostname() throws URISyntaxException {
         FailoverUriPool pool = new FailoverUriPool();
 
         assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672?transport.tcpNoDelay=true"));
+        pool.add(new URI("tcp://somerandomhostname:5672?transport.tcpNoDelay=true"));
         assertFalse(pool.isEmpty());
-        pool.remove(new URI("tcp://SHOULDBEUNRESOLVABLE:5672?transport.tcpNoDelay=true"));
+        pool.remove(new URI("tcp://SOMERANDOMHOSTNAME:5672?transport.tcpNoDelay=true"));
         assertTrue(pool.isEmpty());
-        pool.add(new URI("tcp://shouldbeunresolvable:5672?transport.tcpNoDelay=true"));
+        pool.add(new URI("tcp://somerandomhostname:5672?transport.tcpNoDelay=true"));
         assertFalse(pool.isEmpty());
-        pool.remove(new URI("tcp://shouldbeunresolvable:5673?transport.tcpNoDelay=true"));
+        pool.remove(new URI("tcp://somerandomhostname:5673?transport.tcpNoDelay=true"));
         assertFalse(pool.isEmpty());
     }
 
@@ -367,7 +419,6 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
     }
 
     private void assertConnectedEffectOnPool(boolean randomize, boolean shouldShuffle) {
-
         FailoverUriPool pool = new FailoverUriPool(uris, null);
         pool.setRandomize(randomize);
 
@@ -395,9 +446,9 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
         }
 
         if (shouldShuffle) {
-            assertTrue("URIs did not get randomized", shuffled);
+            assertTrue(shuffled, "URIs did not get randomized");
         } else {
-            assertFalse("URIs should not get randomized", shuffled);
+            assertFalse(shuffled, "URIs should not get randomized");
         }
     }
 
@@ -459,15 +510,74 @@ public class FailoverUriPoolTest extends QpidJmsTestCase {
         }
     }
 
-    private boolean checkIfResolutionWorks() {
-        boolean resolutionWorks = false;
-        try {
-            resolutionWorks = InetAddress.getByName("shouldbeunresolvable") != null;
-            resolutionWorks = InetAddress.getByName("SHOULDBEUNRESOLVABLE") != null;
-            resolutionWorks = InetAddress.getByName("SHOULDBEUNRESOLVABLE2") != null;
-        } catch (Exception e) {
-        }
+    @Test
+    public void testAddURIWhenNestedOptionsSet() throws URISyntaxException {
+        Map<String, String> nested = new HashMap<String, String>();
 
-        return resolutionWorks;
+        nested.put("transport.tcpNoDelay", "true");
+        nested.put("transport.tcpKeepAlive", "false");
+
+        FailoverUriPool pool = new FailoverUriPool(null, nested);
+        assertNotNull(pool.getNestedOptions());
+        assertFalse(pool.getNestedOptions().isEmpty());
+
+        assertTrue(pool.isEmpty());
+        pool.add(uris.get(0));
+        assertFalse(pool.isEmpty());
+        assertEquals(uris.get(0).getHost(), pool.getNext().getHost());
+    }
+
+    @Test
+    public void testAddFirstURIWhenNestedOptionsSet() throws URISyntaxException {
+        Map<String, String> nested = new HashMap<String, String>();
+
+        nested.put("transport.tcpNoDelay", "true");
+        nested.put("transport.tcpKeepAlive", "false");
+
+        FailoverUriPool pool = new FailoverUriPool(null, nested);
+        assertNotNull(pool.getNestedOptions());
+        assertFalse(pool.getNestedOptions().isEmpty());
+
+        assertTrue(pool.isEmpty());
+        pool.addFirst(uris.get(0));
+        assertFalse(pool.isEmpty());
+        assertEquals(uris.get(0).getHost(), pool.getNext().getHost());
+    }
+
+    @Test
+    public void testRemoveAll() throws URISyntaxException {
+        FailoverUriPool pool = new FailoverUriPool(uris, null);
+        assertEquals(uris.size(), pool.size());
+
+        pool.removeAll();
+        assertTrue(pool.isEmpty());
+        assertEquals(0, pool.size());
+
+        pool.removeAll();
+    }
+
+    @Test
+    public void testLoopBackAndLocalHostAllowedInSamePool() throws URISyntaxException {
+        assumeTrue(checkLocalHostResolvesToLoopbackIP());
+
+        FailoverUriPool pool = new FailoverUriPool();
+
+        assertTrue(pool.isEmpty());
+        pool.add(new URI("tcp://127.0.0.1:5672"));
+        assertFalse(pool.isEmpty());
+        assertEquals(1, pool.size());
+        pool.add(new URI("tcp://localhost:5672"));
+        assertEquals(2, pool.size());
+    }
+
+    private boolean checkLocalHostResolvesToLoopbackIP() {
+        try {
+            InetAddress localhost = InetAddress.getByName("localhost");
+            InetAddress loopback = InetAddress.getLoopbackAddress();
+
+            return localhost.equals(loopback);
+        } catch (Exception failsOnError) {
+            return false;
+        }
     }
 }
