@@ -21,10 +21,10 @@ import static org.apache.qpid.jms.provider.amqp.AmqpSupport.OPEN_HOSTNAME;
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.PATH;
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.PORT;
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.SCHEME;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.net.URI;
 import java.util.HashMap;
@@ -41,13 +41,11 @@ import org.apache.qpid.jms.JmsConnectionExtensions;
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.transports.TransportOptions;
-import org.apache.qpid.jms.transports.netty.NettySimpleAmqpServer.ConnectionIntercepter;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.transport.ConnectionError;
 import org.apache.qpid.proton.amqp.transport.ErrorCondition;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TestName;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -61,10 +59,8 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
 
     private static final Logger LOG = LoggerFactory.getLogger(NettyTcpToMockServerTest.class);
 
-    @Rule
-    public TestName test = new TestName();
-
-    @Test(timeout = 60 * 1000)
+    @Test
+    @Timeout(60)
     public void testConnectToServer() throws Exception {
         try (NettySimpleAmqpServer server = createServer(createServerOptions())) {
             server.start();
@@ -83,7 +79,8 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 60 * 1000)
+    @Test
+    @Timeout(60)
     public void testServerEnforcesExclusiveContainerCapability() throws Exception {
         try (NettySimpleAmqpServer server = createServer(createServerOptions())) {
             server.setAllowNonSaslConnections(true);
@@ -93,14 +90,14 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
             Connection connection = null;
             try {
                 connection = cf.createConnection();
-                connection.setClientID(test.getMethodName());
+                connection.setClientID(_testMethodName);
             } catch (Exception ex) {
                 LOG.info("Caught exception while attempting to connect");
                 fail("Should not throw an exception for this connection");
             }
 
             try {
-                cf.createConnection().setClientID(test.getMethodName());
+                cf.createConnection().setClientID(_testMethodName);
                 fail("Should throw an exception when for duplicate client ID");
             } catch (InvalidClientIDException ex) {
                 LOG.info("Caught exception while attempting to connect");
@@ -113,7 +110,8 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 60 * 1000)
+    @Test
+    @Timeout(60)
     public void testConnectToServerFailsWhenSaslDisabled() throws Exception {
         try (NettySimpleAmqpServer server = createServer(createServerOptions())) {
             server.start();
@@ -127,12 +125,15 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
             } catch (Exception ex) {
                 LOG.info("Caught expected exception while attempting to connect");
             } finally {
-                connection.close();
+                if (connection != null) {
+                    connection.close();
+                }
             }
         }
     }
 
-    @Test(timeout = 60 * 1000)
+    @Test
+    @Timeout(60)
     public void testConnectToServerWhenSaslDisabledAndServerAllowsIt() throws Exception {
         try (NettySimpleAmqpServer server = createServer(createServerOptions())) {
             server.setAllowNonSaslConnections(true);
@@ -152,45 +153,39 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 60 * 1000)
+    @Test
+    @Timeout(60)
     public void testConnectToServerWhenRedirected() throws Exception {
         try (NettySimpleAmqpServer server = createServer(createServerOptions());
              NettySimpleAmqpServer redirect = createServer(createServerOptions())) {
 
             final CountDownLatch redirectComplete = new CountDownLatch(1);
 
-            server.setConnectionIntercepter(new ConnectionIntercepter() {
+            server.setConnectionIntercepter((protonConnection) -> {
 
-                @Override
-                public ErrorCondition interceptConnectionAttempt(org.apache.qpid.proton.engine.Connection connection) {
-                    ErrorCondition redirection = new ErrorCondition(ConnectionError.REDIRECT,
-                        "Server redirecting connection.");
+                ErrorCondition redirection = new ErrorCondition(ConnectionError.REDIRECT,
+                    "Server redirecting connection.");
 
-                    URI serverURI = null;
-                    try {
-                        serverURI = redirect.getConnectionURI();
-                    } catch (Exception e) {
-                        new RuntimeException();
-                    }
-
-                    // Create standard redirection condition
-                    Map<Symbol, Object> infoMap = new HashMap<Symbol, Object> ();
-                    infoMap.put(OPEN_HOSTNAME, serverURI.getHost());
-                    infoMap.put(NETWORK_HOST, serverURI.getHost());
-                    infoMap.put(PORT, serverURI.getPort());
-                    redirection.setInfo(infoMap);
-
-                    return redirection;
+                URI serverURI = null;
+                try {
+                    serverURI = redirect.getConnectionURI();
+                } catch (Exception e) {
+                    new RuntimeException();
                 }
+
+                // Create standard redirection condition
+                Map<Symbol, Object> infoMap = new HashMap<Symbol, Object> ();
+                infoMap.put(OPEN_HOSTNAME, serverURI.getHost());
+                infoMap.put(NETWORK_HOST, serverURI.getHost());
+                infoMap.put(PORT, serverURI.getPort());
+                redirection.setInfo(infoMap);
+
+                return redirection;
             });
 
-            redirect.setConnectionIntercepter(new ConnectionIntercepter() {
-
-                @Override
-                public ErrorCondition interceptConnectionAttempt(org.apache.qpid.proton.engine.Connection connection) {
-                    redirectComplete.countDown();
-                    return null;
-                }
+            redirect.setConnectionIntercepter((protonConnection) -> {
+                redirectComplete.countDown();
+                return null;
             });
 
             server.start();
@@ -224,7 +219,8 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 20 * 1000)
+    @Test
+    @Timeout(20)
     public void testConnectToWSServerWhenRedirectedWithNewPath() throws Exception {
         try (NettySimpleAmqpServer primary = createWSServer(createServerOptions());
              NettySimpleAmqpServer redirect = createWSServer(createServerOptions())) {
@@ -234,40 +230,33 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
             primary.setWebSocketPath("/primary");
             redirect.setWebSocketPath("/redirect");
 
-            primary.setConnectionIntercepter(new ConnectionIntercepter() {
+            primary.setConnectionIntercepter((protonConnection) -> {
 
-                @Override
-                public ErrorCondition interceptConnectionAttempt(org.apache.qpid.proton.engine.Connection connection) {
-                    ErrorCondition redirection = new ErrorCondition(ConnectionError.REDIRECT,
-                        "Server redirecting connection.");
+                ErrorCondition redirection = new ErrorCondition(ConnectionError.REDIRECT,
+                    "Server redirecting connection.");
 
-                    URI serverURI = null;
-                    try {
-                        serverURI = redirect.getConnectionURI();
-                    } catch (Exception e) {
-                        new RuntimeException();
-                    }
-
-                    // Create standard redirection condition
-                    Map<Symbol, Object> infoMap = new HashMap<Symbol, Object> ();
-                    infoMap.put(OPEN_HOSTNAME, serverURI.getHost());
-                    infoMap.put(NETWORK_HOST, serverURI.getHost());
-                    infoMap.put(PORT, serverURI.getPort());
-                    infoMap.put(PATH, redirect.getWebSocketPath());
-                    infoMap.put(SCHEME, redirect.isSecureServer() ? "wss" : "ws");
-                    redirection.setInfo(infoMap);
-
-                    return redirection;
+                URI serverURI = null;
+                try {
+                    serverURI = redirect.getConnectionURI();
+                } catch (Exception e) {
+                    new RuntimeException();
                 }
+
+                // Create standard redirection condition
+                Map<Symbol, Object> infoMap = new HashMap<Symbol, Object> ();
+                infoMap.put(OPEN_HOSTNAME, serverURI.getHost());
+                infoMap.put(NETWORK_HOST, serverURI.getHost());
+                infoMap.put(PORT, serverURI.getPort());
+                infoMap.put(PATH, redirect.getWebSocketPath());
+                infoMap.put(SCHEME, redirect.isSecureServer() ? "wss" : "ws");
+                redirection.setInfo(infoMap);
+
+                return redirection;
             });
 
-            redirect.setConnectionIntercepter(new ConnectionIntercepter() {
-
-                @Override
-                public ErrorCondition interceptConnectionAttempt(org.apache.qpid.proton.engine.Connection connection) {
-                    redirectComplete.countDown();
-                    return null;
-                }
+            redirect.setConnectionIntercepter((protonConnection) -> {
+                redirectComplete.countDown();
+                return null;
             });
 
             primary.start();
@@ -301,7 +290,8 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 60000)
+    @Test
+    @Timeout(60)
     public void testConnectToWSServerWithHttpHeaderConnectionExtensions() throws Exception {
         try (NettySimpleAmqpServer server = createWSServer(createServerOptions())) {
             server.start();
@@ -325,9 +315,9 @@ public class NettyTcpToMockServerTest extends QpidJmsTestCase {
                 connection = cf.createConnection();
                 connection.start();
 
-                assertTrue("HandshakeCompletion not set within given time", server.awaitHandshakeCompletion(2000));
+                assertTrue(server.awaitHandshakeCompletion(2000), "HandshakeCompletion not set within given time");
                 HandshakeComplete handshake = server.getHandshakeComplete();
-                assertNotNull("completion should not be null", handshake);
+                assertNotNull(handshake, "completion should not be null");
                 HttpHeaders requestHeaders = handshake.requestHeaders();
 
                 assertTrue(requestHeaders.contains("test-header1"));
