@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -25,6 +25,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.Vector;
+import java.util.concurrent.TimeUnit;
 
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
@@ -55,10 +56,9 @@ import org.apache.activemq.security.SimpleAuthenticationPlugin;
 import org.apache.activemq.security.TempDestinationAuthorizationEntry;
 import org.apache.activemq.store.kahadb.KahaDBStore;
 import org.apache.activemq.util.JMXSupport;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.rules.TestName;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestInfo;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -71,8 +71,6 @@ public class QpidJmsTestSupport {
 
     public static final String KAHADB_DIRECTORY = "target/activemq-data";
 
-    @Rule public TestName name = new TestName();
-
     protected static final Logger LOG = LoggerFactory.getLogger(QpidJmsTestSupport.class);
     protected BrokerService brokerService;
     protected final List<BrokerService> brokers = new ArrayList<BrokerService>();
@@ -80,15 +78,17 @@ public class QpidJmsTestSupport {
     protected int numberOfMessages;
     protected Connection connection;
 
-    @Before
-    public void setUp() throws Exception {
+    protected String testMethodName;
+    @BeforeEach
+    public void setUp(TestInfo testInfo) throws Exception {
+        this.testMethodName = testInfo.getTestMethod().get().getName();
         LOG.info("========== setUp " + getTestName() + " ==========");
         exceptions.clear();
         startPrimaryBroker();
         this.numberOfMessages = 2000;
     }
 
-    @After
+    @AfterEach
     public void tearDown() throws Exception {
         LOG.info("========== tearDown " + getTestName() + " ==========");
         Exception firstError = null;
@@ -124,7 +124,7 @@ public class QpidJmsTestSupport {
     }
 
     public String getDestinationName() {
-        return name.getMethodName();
+        return testMethodName;
     }
 
     public URI getBrokerActiveMQClientConnectionURI() {
@@ -139,6 +139,14 @@ public class QpidJmsTestSupport {
         return false;
     }
 
+    protected boolean isConcurrentStoreAndDispatchQueues() {
+        return false;
+    }
+
+    protected boolean isConcurrentStoreAndDispatchTopics() {
+        return false;
+    }
+
     protected boolean isAdvisorySupport() {
         return false;
     }
@@ -166,26 +174,32 @@ public class QpidJmsTestSupport {
         brokerService.setUseJmx(true);
         brokerService.getManagementContext().setCreateConnector(false);
         brokerService.setDataDirectory("target/" + name);
+        brokerService.setKeepDurableSubsActive(false);
+
         if (isPersistent()) {
             KahaDBStore kaha = new KahaDBStore();
             kaha.setDirectory(new File(KAHADB_DIRECTORY + "/" + name));
+            kaha.setConcurrentStoreAndDispatchQueues(isConcurrentStoreAndDispatchQueues());
+            kaha.setConcurrentStoreAndDispatchTopics(isConcurrentStoreAndDispatchTopics());
+            kaha.setCheckpointInterval(TimeUnit.MINUTES.toMillis(5));
             brokerService.setPersistenceAdapter(kaha);
         }
-        brokerService.setStoreOpenWireVersion(10);
 
         configureBrokerPolicies(brokerService);
 
         ArrayList<BrokerPlugin> plugins = new ArrayList<BrokerPlugin>();
         BrokerPlugin authenticationPlugin = configureAuthentication();
         if (authenticationPlugin != null) {
-            plugins.add(configureAuthorization());
+            plugins.add(authenticationPlugin);
         }
 
         BrokerPlugin authorizationPlugin = configureAuthorization();
         if (authorizationPlugin != null) {
-            plugins.add(configureAuthentication());
+            plugins.add(authorizationPlugin);
         }
 
+        addAdditionalBrokerPlugins(plugins);
+
         if (!plugins.isEmpty()) {
             BrokerPlugin[] array = new BrokerPlugin[plugins.size()];
             brokerService.setPlugins(plugins.toArray(array));
@@ -196,6 +210,10 @@ public class QpidJmsTestSupport {
         return brokerService;
     }
 
+    protected void addAdditionalBrokerPlugins(List<BrokerPlugin> plugins) {
+        // Subclasses can add their own plugins, we don't add any here.
+    }
+
     protected void addAdditionalConnectors(BrokerService brokerService, Map<String, Integer> portMap) throws Exception {
         // Subclasses can add their own connectors, we don't add any here.
     }
@@ -367,7 +385,7 @@ public class QpidJmsTestSupport {
     protected void sendToAmqQueue(int count) throws Exception {
         Connection activemqConnection = createActiveMQConnection();
         Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue amqTestQueue = amqSession.createQueue(name.getMethodName());
+        Queue amqTestQueue = amqSession.createQueue(testMethodName);
         sendMessages(activemqConnection, amqTestQueue, count);
         activemqConnection.close();
     }
@@ -375,7 +393,7 @@ public class QpidJmsTestSupport {
     protected void sendToAmqTopic(int count) throws Exception {
         Connection activemqConnection = createActiveMQConnection();
         Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Topic amqTestTopic = amqSession.createTopic(name.getMethodName());
+        Topic amqTestTopic = amqSession.createTopic(testMethodName);
         sendMessages(activemqConnection, amqTestTopic, count);
         activemqConnection.close();
     }
@@ -455,15 +473,15 @@ public class QpidJmsTestSupport {
         return false;
     }
 
-    protected boolean isAlwaysSyncSend() {
+    protected boolean isForceSyncSends() {
         return false;
     }
 
-    protected boolean isSendAcksAsync() {
+    protected boolean isForceAsyncAcks() {
         return false;
     }
 
     protected String getTestName() {
-        return getClass().getSimpleName() + "." + name.getMethodName();
+        return getClass().getSimpleName() + "." + testMethodName;
     }
 }
